.. SPDX-License-Identifier: MPL-2.0
.. SPDX-FileCopyrightText: 2023 igo95862

Welcome to python-lxns documentation!
=====================================

``python-lxns`` is a library to interact with Linux kernel namespaces.

The library is split in to different modules each implementing
a different area of functionality:

.. toctree::

    namespace
    tips_and_tricks
